@@ -1,5 +1,47 @@
 import Orange
 from packaging import version
+
+import sys
+import re
+import os
+def check_executable_path():
+    exe = sys.executable
+
+    # caractères spéciaux interdits (tu peux en ajouter)
+    forbidden = r'[^A-Za-z0-9_\-./:\\]'  # tout ce qui n'est PAS ce set
+    pattern = re.compile(forbidden)
+
+    if " " in exe or pattern.search(exe):
+        return False
+    return True
+
+if not check_executable_path():
+    if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
+        from orangecontrib.AAIT.utils import SimpleDialogQt
+    else:
+        from orangecontrib.AAIT.utils import SimpleDialogQt
+    SimpleDialogQt.BoxError("You must install this program in a path that does not contain spaces or special characters.")
+    exit(0)
+
+def check_executable_length(max_length=260):
+    exe = sys.executable
+    length = len(exe)
+
+    if length > max_length:
+        print(f"ERROR: The installation path is too long ({length} characters). "
+              f"Maximum allowed is {max_length}.")
+        return False
+    return True
+
+if not check_executable_length():
+    if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
+        from orangecontrib.AAIT.utils import SimpleDialogQt
+    else:
+        from orangecontrib.AAIT.utils import SimpleDialogQt
+    SimpleDialogQt.BoxError("The installation path is too long. Please choose a shorter path..")
+    exit(0)
+
+
 target_version = version.parse("3.37")
 current_version = version.parse(Orange.version.version)
 if current_version < target_version: # Skip the file
