@@ -4,17 +4,25 @@ import Orange
 from Orange.data import Domain, Table, StringVariable, ContinuousVariable
 from chonkie import TokenChunker, WordChunker, SentenceChunker
 
-def create_chunks(table, model, chunk_size=500, overlap=125, mode="words", progress_callback=None, argself=None):
+def create_chunks(table, model, column_name, chunk_size=500, overlap=125, mode="words", progress_callback=None, argself=None):
     """
-    Chunk the text contained in the column "content" of an input table, with the help of an embedding model.
+    Chunk the text in `column_name` of an Orange Table.
+
+    Splits each row's text into overlapping chunks (by words or characters),
+    optionally reporting progress. Rows producing multiple chunks are duplicated.
 
     Parameters:
-        table (Table): The input table to process
-        model (SentenceTransformer): The embeddings model to process the text.
-        mode (str): chunking mode
+        table (Table): Input data table.
+        model: Embedding model used by the chunking pipeline.
+        column_name (str): Name of the text column to chunk.
+        chunk_size (int): Target chunk size.
+        overlap (int): Overlap between chunks.
+        mode (str): "words" or "characters".
+        progress_callback (callable): Optional progress reporter.
+        argself: Optional caller reference.
 
     Returns:
-        out_data (Table): The data table with a column "Chunks" (and more rows if several chunks were obtained per text)
+        Table: A new table with one row per chunk and a "Chunks" column.
     """
     data = copy.deepcopy(table)
 
@@ -38,7 +46,7 @@ def create_chunks(table, model, chunk_size=500, overlap=125, mode="words", progr
 
     new_rows = []
     for i, row in enumerate(data):
-        content = row["content"].value
+        content = row[column_name].value
         chunks, metadatas = chunk_function(content, tokenizer=model.tokenizer, chunk_size=chunk_size, chunk_overlap=overlap)
         # For each chunk in the chunked data
         for j, chunk in enumerate(chunks):
