@@ -2,25 +2,24 @@ import os
 import sys
 
 import Orange.data
+from Orange.data import StringVariable
 from AnyQt.QtWidgets import QApplication
-from Orange.widgets import widget
+from Orange.widgets.settings import Setting
 from Orange.widgets.utils.signals import Input, Output
 from sentence_transformers import SentenceTransformer
 
 if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
     from Orange.widgets.orangecontrib.AAIT.llm import embeddings
-    from Orange.widgets.orangecontrib.AAIT.utils import thread_management
-    from Orange.widgets.orangecontrib.AAIT.utils.import_uic import uic
+    from Orange.widgets.orangecontrib.AAIT.utils import thread_management, base_widget
     from Orange.widgets.orangecontrib.AAIT.utils.initialize_from_ini import apply_modification_from_python_file
 else:
     from orangecontrib.AAIT.llm import embeddings
-    from orangecontrib.AAIT.utils import thread_management
-    from orangecontrib.AAIT.utils.import_uic import uic
+    from orangecontrib.AAIT.utils import thread_management, base_widget
     from orangecontrib.AAIT.utils.initialize_from_ini import apply_modification_from_python_file
 
 
 @apply_modification_from_python_file(filepath_original_widget=__file__)
-class OWCreateEmbeddings(widget.OWWidget):
+class OWCreateEmbeddings(base_widget.BaseListWidget):
     name = "Create Embeddings"
     description = "Create embeddings on the column 'content' of a Table"
     category = "AAIT - LLM INTEGRATION"
@@ -31,6 +30,9 @@ class OWCreateEmbeddings(widget.OWWidget):
     want_control_area = False
     priority = 1060
 
+    # Settings
+    selected_column_name = Setting("content")
+
     class Inputs:
         data = Input("Data", Orange.data.Table)
         model = Input("Model", SentenceTransformer, auto_summary=False)
@@ -40,10 +42,10 @@ class OWCreateEmbeddings(widget.OWWidget):
 
     @Inputs.data
     def set_data(self, in_data):
-        if in_data is None:
-            self.Outputs.data.send(None)
-            return
         self.data = in_data
+        if self.data:
+            self.var_selector.add_variables(self.data.domain)
+            self.var_selector.select_variable_by_name(self.selected_column_name)
         if self.autorun:
             self.run()
 
@@ -57,8 +59,8 @@ class OWCreateEmbeddings(widget.OWWidget):
         super().__init__()
         # Qt Management
         self.setFixedWidth(470)
-        self.setFixedHeight(300)
-        uic.loadUi(self.gui, self)
+        self.setFixedHeight(450)
+        #uic.loadUi(self.gui, self)
 
         # Data Management
         self.data = None
@@ -69,26 +71,28 @@ class OWCreateEmbeddings(widget.OWWidget):
         self.post_initialized()
 
     def run(self):
+        self.error("")
+        self.warning("")
+
         # if thread is running quit
         if self.thread is not None:
             self.thread.safe_quit()
 
         if self.data is None:
+            self.Outputs.data.send(None)
             return
 
         if self.model is None:
+            self.Outputs.data.send(None)
             return
 
         # Verification of in_data
-        self.error("")
-        try:
-            self.data.domain["content"]
-        except KeyError:
-            self.error('You need a "content" column in input data')
+        if not self.selected_column_name in self.data.domain:
+            self.warning(f'Previously selected column "{self.selected_column_name}" does not exist in your data.')
             return
 
-        if type(self.data.domain["content"]).__name__ != 'StringVariable':
-            self.error('"content" column needs to be a Text')
+        if not isinstance(self.data.domain[self.selected_column_name], StringVariable):
+            self.error('You must select a text variable.')
             return
 
         # Start progress bar
@@ -98,7 +102,7 @@ class OWCreateEmbeddings(widget.OWWidget):
         # --> progress is used in the main function to track progress (with a callback)
         # --> result is used to collect the result from main function
         # --> finish is just an empty signal to indicate that the thread is finished
-        self.thread = thread_management.Thread(embeddings.create_embeddings, self.data, self.model)
+        self.thread = thread_management.Thread(embeddings.create_embeddings, self.data, self.model, self.selected_column_name)
         self.thread.progress.connect(self.handle_progress)
         self.thread.result.connect(self.handle_result)
         self.thread.finish.connect(self.handle_finish)
