@@ -92,10 +92,9 @@ def tokens_to_row(table):
         for token in tokens:
             # Duplicate the row's values
             attrs = list(row)  # attribute values
-            class_vars = list(row.get_class()) if domain.class_vars else []
             metas = list(row.metas) + [token]  # append token as a new meta
 
-            new_data_rows.append(attrs + class_vars + metas)
+            new_data_rows.append(attrs + metas)
 
     # Build and return the new Table
     return Table.from_list(new_domain, new_data_rows)
@@ -122,10 +121,9 @@ def tokens_to_column(table):
 
         # Build row: attributes + class_vars + metas + tokens
         attrs = list(row)
-        class_vars = list(row.get_class()) if table.domain.class_vars else []
         metas = list(row.metas) + padded_tokens
 
-        new_data_rows.append(attrs + class_vars + metas)
+        new_data_rows.append(attrs + metas)
 
     return Table.from_list(new_domain, new_data_rows)
 
