@@ -1,7 +1,7 @@
 import os
 from AnyQt.QtWidgets import QPushButton, QApplication, QRadioButton, QComboBox,QCheckBox,QLineEdit
 import sys
-
+import numpy as np
 from Orange.widgets.settings import Setting
 from Orange.widgets.widget import OWWidget, Output, Input
 from Orange.data import Table, Domain, StringVariable
@@ -75,10 +75,7 @@ class OWInputSelector(OWWidget):
             self.comboBox.setCurrentIndex(0)  # Sélectionner le premier item
 
 
-        if self.str_checkBox_3_send != "False":
-            self.checkBox_3_send.setChecked(True)
-        else:
-            self.checkBox_3_send.setChecked(False)
+
 
         if self.str_Launch_automatically_on_startup != "False":
             self.checkBox_launch_at_startup.setChecked(True)
@@ -102,10 +99,7 @@ class OWInputSelector(OWWidget):
             self.str_Launch_automatically_on_startup ="False"
 
 
-        if self.checkBox_3_send.isChecked():
-            self.str_checkBox_3_send = "True"
-        else:
-            self.str_checkBox_3_send ="False"
+
         if self.radioButton.isChecked():
             self.select_folder_radio_button_checked=True
             self.update_qt_view_from_settings()
@@ -151,13 +145,8 @@ class OWInputSelector(OWWidget):
         self.lineEdit=self.findChild(QLineEdit,'lineEdit')
         self.lineEdit.setText(self.line_edit_value)
         self.windowTitleEdit = self.findChild(QLineEdit, 'lineEdit_window_title')
-        self.checkBox_3_send = self.findChild(QCheckBox, 'checkBox_3_send')
         self.checkBox_launch_at_startup = self.findChild(QCheckBox, 'checkBox_launch_at_startup')
 
-        if self.str_checkBox_3_send=="True":
-            self.checkBox_3_send.setChecked(True)
-        else:
-            self.checkBox_3_send.setChecked(False)
 
 
         if self.str_Launch_automatically_on_startup=="True":
@@ -280,7 +269,6 @@ class OWInputSelector(OWWidget):
         self.radioButton2.clicked.connect(self.update_setting_from_qt_view)
         self.checkBox.clicked.connect(self.update_setting_from_qt_view)
         self.checkBox_new_file.clicked.connect(self.update_setting_from_qt_view)
-        self.checkBox_3_send.clicked.connect(self.update_setting_from_qt_view)
         self.checkBox_launch_at_startup.clicked.connect(self.update_setting_from_qt_view)
 
 
@@ -361,8 +349,6 @@ class OWInputSelector(OWWidget):
     @Inputs.input_table
     def input_table(self, data):
         self.in_data = data
-        # if self.str_checkBox_3_send=="False":
-        #     return
         if data is not None:
             self.launch_fucntionalities()
 
@@ -404,7 +390,7 @@ class OWInputSelector(OWWidget):
                 file_filter=file_filter,
                 dialog_title=dialog_title
             )
-        if sys.platform.startswith("Darwin"):
+        if sys.platform.startswith("Darwin") or sys.platform.startswith("darwin") :
             return  mac_utils.select_file_macos(
                 multi_select=multi_select,
                 file_filter=file_filter,
@@ -417,16 +403,15 @@ class OWInputSelector(OWWidget):
             "",  # initial directory
             file_filter  # filter
         )
+        files=files[0]
         return files
 
     def select_new_file(self, file_filter, dialog_title):
         if os.name == 'nt':
             return windows_utils.select_new_file_ctypes(file_filter=file_filter, dialog_title=dialog_title)
-        if sys.platform.startswith("Darwin"):
+        if sys.platform.startswith("Darwin") or sys.platform.startswith("darwin"):
             return mac_utils.select_new_file_macos(file_filter=file_filter, dialog_title=dialog_title)
 
-
-        print("a faire correctement sans qt sur mac (et linux")
         from AnyQt.QtWidgets import QFileDialog
         files, _ = QFileDialog.getSaveFileName(
             self,  # parent
@@ -439,7 +424,7 @@ class OWInputSelector(OWWidget):
     def select_folder(self, dialog_title):
         if os.name=='nt':
             return windows_utils.select_folder_ctypes(title=dialog_title)
-        if sys.platform.startswith("Darwin"):
+        if sys.platform.startswith("Darwin") or sys.platform.startswith("darwin"):
             return mac_utils.select_folder_macos(title=dialog_title)
 
         # a faire correctement sans qt sur mac
@@ -458,7 +443,76 @@ class OWInputSelector(OWWidget):
             return
 
         var = StringVariable("path")
+        separator = "//////"
 
+
+        if separator in self.selected_path:
+            # plusieurs fichiers
+
+            paths = self.selected_path.split(separator)
+            n_paths = len(paths)
+
+            if self.in_data is not None:
+                base = self.in_data
+                old_dom = base.domain
+
+                # Domaine = attributs + classes existants + nouvelle méta "path"
+                domain = Domain(
+                    old_dom.attributes,
+                    old_dom.class_vars,
+                    list(old_dom.metas) + [var]
+                )
+
+                m_in = len(base)
+                n_rows = max(m_in, n_paths)  # on peut devoir ajouter des lignes
+                n_attr = len(domain.attributes)
+                n_cls = len(domain.class_vars)
+                n_meta = len(domain.metas)
+
+                # Prépare des tableaux de la bonne taille
+                X_new = np.full((n_rows, n_attr), np.nan) if n_attr else np.empty((n_rows, 0))
+                # Y doit être 2D si des class_vars existent, sinon None
+                Y_new = (np.full((n_rows, n_cls), np.nan) if n_cls else None)
+
+                metas_new = np.empty((n_rows, n_meta), dtype=object)
+                # Initialiser chaque colonne de méta avec sa valeur "Unknown" Orange
+                for j, meta_var in enumerate(domain.metas):
+                    unknown = getattr(meta_var, "Unknown", None)
+                    metas_new[:, j] = unknown
+
+                # Copie des données existantes dans la partie haute
+                if m_in:
+                    if n_attr:
+                        X_new[:m_in, :] = base.X
+                    if n_cls:
+                        # Base.Y peut être 1D si une seule classe : on normalise en 2D
+                        if base.Y is not None:
+                            if np.ndim(base.Y) == 1 and n_cls == 1:
+                                Y_new[:m_in, 0] = base.Y
+                            else:
+                                Y_new[:m_in, :] = base.Y
+                    if len(old_dom.metas):
+                        metas_new[:m_in, :n_meta - 1] = base.metas  # on laisse la dernière col vide (path)
+
+                # Remplit la nouvelle colonne "path" pour les N premières lignes
+                metas_new[:n_paths, -1] = paths
+
+                new_table = Table.from_numpy(domain, X_new, Y_new, metas_new)
+
+            else:
+                # Pas de table en entrée : on crée une table uniquement avec la méta "path"
+                n_rows = max(n_paths, 1)  # au moins 1 ligne
+                domain = Domain([], metas=[var])
+
+                metas_new = np.empty((n_rows, 1), dtype=object)
+                metas_new[:, 0] = ""  # vide par défaut
+                metas_new[:n_paths, 0] = paths
+
+                X_dummy = np.empty((n_rows, 0))
+                new_table = Table.from_numpy(domain, X_dummy, None, metas_new)
+            self.Outputs.path.send(new_table)
+            self.Outputs.path_string.send(str(paths))
+            return
         if self.in_data is not None:
             domain = Domain(
                 self.in_data.domain.attributes,
